# archer_nlp

nlp数据处理工具及模型。

# 依赖

* beautifulsoup4==4.11.1
* numpy==1.19.5
* pandas==1.4.2
* pymongo==3.11.0
* PyMySQL==1.0.2
* python_Levenshtein==0.12.2
* requests==2.27.1
* setuptools==58.0.4

# 功能

* 读写Excel、json、pickle
* 生成uuid，字典
* 当前时间格式化，如“2022-03-03 16:12:30”
* 编辑距离最相似匹配
* 操作mongodb
* 操作mysql
* 爬虫工具库
* 按标点和最大长度分句